==> haskell-asn1-encoding-0.9.3-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-asn1-encoding/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-encoding
version: 0.9.3
id: asn1-encoding-0.9.3-61b8646033da9bb10b3d5eef2c9988e8
key: asn1e_GyaJpTCz0m93p9MwtJXM8v
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-asn1
synopsis: ASN1 data reader and writer in RAW, BER and DER forms
description:
    ASN1 data reader and writer in raw form with supports for high level forms of ASN1 (BER, and DER).
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.ASN1.Error Data.ASN1.BinaryEncoding
    Data.ASN1.BinaryEncoding.Raw Data.ASN1.Encoding Data.ASN1.Stream
    Data.ASN1.Object
hidden-modules: Data.ASN1.Prim Data.ASN1.BinaryEncoding.Parse
                Data.ASN1.BinaryEncoding.Writer Data.ASN1.Internal
                Data.ASN1.Serialize Data.ASN1.Get
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/asn1-encoding-0.9.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/asn1-encoding-0.9.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/asn1-encoding-0.9.3
hs-libraries: HSasn1-encoding-0.9.3-GyaJpTCz0m93p9MwtJXM8v
depends:
    asn1-types-0.3.2-373d90c7a1b36e8b9d0fe76023835d30
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    hourglass-0.2.9-d44f07201da9fd2656b62ae800dd5aa9
haddock-interfaces: /usr/share/doc/haskell-asn1-encoding/html/asn1-encoding.haddock
haddock-html: /usr/share/doc/haskell-asn1-encoding/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-encoding-0.9.3-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-asn1-encoding/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-encoding
version: 0.9.3
id: asn1-encoding-0.9.3-973a6b8f38afc857f3a60ad311c8ee45
key: asn1e_A0jeMIoYyiZ4PSPkybrUpF
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-asn1
synopsis: ASN1 data reader and writer in RAW, BER and DER forms
description:
    ASN1 data reader and writer in raw form with supports for high level forms of ASN1 (BER, and DER).
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.ASN1.Error Data.ASN1.BinaryEncoding
    Data.ASN1.BinaryEncoding.Raw Data.ASN1.Encoding Data.ASN1.Stream
    Data.ASN1.Object
hidden-modules: Data.ASN1.Prim Data.ASN1.BinaryEncoding.Parse
                Data.ASN1.BinaryEncoding.Writer Data.ASN1.Internal
                Data.ASN1.Serialize Data.ASN1.Get
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/asn1-encoding-0.9.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/asn1-encoding-0.9.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/asn1-encoding-0.9.3
hs-libraries: HSasn1-encoding-0.9.3-A0jeMIoYyiZ4PSPkybrUpF
depends:
    asn1-types-0.3.2-3969820adc8283f126affe054010f830
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    hourglass-0.2.10-b11bcf654d7049575fb45d24076b832b
haddock-interfaces: /usr/share/doc/haskell-asn1-encoding/html/asn1-encoding.haddock
haddock-html: /usr/share/doc/haskell-asn1-encoding/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
